unit DNSMain;

interface

uses Windows, Messages, SysUtils, Classes, Controls, Forms, StdCtrls, ComCtrls,
     IniFiles, Resolver;

const WM_NextQuery=WM_USER+200;

type
  TFrmDNS = class(TForm)
    EdServer: TComboBox;
    ListQuery: TMemo; ListAnswer: TMemo;
    BtnCon: TButton; BtnResolve: TButton; BtnDis: TButton;
    StatusBar: TStatusBar;
    Label1: TLabel; Label2: TLabel; Label3: TLabel;
    Resolv: TResolver;
    procedure FormCreate(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure BtnConClick(Sender: TObject);
    procedure BtnDisClick(Sender: TObject);
    procedure BtnResolveClick(Sender: TObject);
    procedure OnResolvAnswer(Sender: TObject);
    procedure OnResolvError(Sender: TObject; ErrorMsg: String);
    procedure OnResolvConnect(Sender: TObject);
    procedure EdServerKeyPress(Sender: TObject; var Key: Char);
    procedure EdServerExit(Sender: TObject);
  private
    nQuery: Integer;
    EdServerChanged: Boolean;
    procedure DoNextQuery(var Msg: TMessage); message WM_NextQuery;
  end;

var FrmDNS: TFrmDNS;

implementation {$R *.DFM}

procedure TFrmDNS.FormCreate(Sender: TObject);
var Ini: TIniFile; i: Integer; sBuf: String;
begin
 Ini:=TIniFile.Create(ChangeFileExt(Application.ExeName,'.ini'));
 Left:=Ini.ReadInteger('Position','links',1);
 Top:=Ini.ReadInteger('Position','oben',1);
 i:=1;
 repeat                                    // Serverliste in Combobox einlesen
  sBuf:=Ini.ReadString('Server',IntToStr(i),'');
  if Length(sBuf)<>0 then EdServer.Items.Add(sBuf);
  Inc(i);
 until Length(sBuf)=0;
 EdServer.Text:=Ini.ReadString('Server','Server','pns.dtag.de');
 Ini.Free;
end;

procedure TFrmDNS.FormClose(Sender: TObject; var Action: TCloseAction);
var Ini: TIniFile; i: Integer;
begin
 if Resolv.Active then Resolv.Close;
 Ini:=TIniFile.Create(ChangeFileExt(Application.ExeName,'.INI'));
 try                             // falls das Demo von CD luft (Schreibschutz)
  Ini.WriteString('Server','Server',EdServer.Text);
  for i:=1 to EdServer.Items.Count do
   Ini.WriteString('Server',IntToStr(i),EdServer.Items[i-1]);
  Ini.WriteInteger('Position','links',Left);
  Ini.WriteInteger('Position','oben',Top);
 except end;                        // keine Exception anzeigen, einfach weiter
 Ini.Free;
end;

procedure TFrmDNS.BtnConClick(Sender: TObject);           // Button "verbinden"
begin
 nQuery:=0;
 ListAnswer.Lines.Clear;
 StatusBar.SimpleText:='Verbindungsaufnahme';
 Resolv.Server:=EdServer.Text;
 Resolv.Connect;
end;

procedure TFrmDNS.OnResolvConnect(Sender: TObject);  // bei Verbindungsaufnahme
begin
 BtnResolve.Enabled:=true; BtnCon.Enabled:=false;
 StatusBar.SimpleText:='Verbindung hergestellt'
end;

procedure TFrmDNS.BtnDisClick(Sender: TObject);             // Button "trennen"
begin
 Resolv.Close;
 BtnCon.Enabled:=true;
 StatusBar.SimpleText:='Verbindung beendet';
end;

procedure TFrmDNS.BtnResolveClick(Sender: TObject);    // eine Abfrage auslsen
begin
 if nQuery<ListQuery.Lines.Count then begin
  StatusBar.SimpleText:='Abfrage senden';
  Resolv.Query(ListQuery.Lines[nQuery]);
 end else begin
  BtnResolve.Enabled:=false;
  StatusBar.SimpleText:='Auftrag beendet';
 end;
end;

procedure TFrmDNS.OnResolvAnswer(Sender: TObject);      // Antwort eingetroffen
var sErg: String;
begin
 sErg:=Resolv.Answer;
 if Length(sErg)=0 then sErg:='???';
 ListAnswer.Lines.Add(sErg);
 StatusBar.SimpleText:='Antwort gelesen';
 PostMessage(Handle,WM_NextQuery,1,1);           // nchste Anfrage vorbereiten
end;

procedure TFrmDNS.DoNextQuery(var Msg: TMessage);
begin
 Inc(nQuery);                                                // nchste Anfrage
 BtnResolveClick(Self);                                     // Anfrage auslsen
end;

procedure TFrmDNS.OnResolvError(Sender: TObject; ErrorMsg: String);
begin StatusBar.SimpleText:=ErrorMsg; MessageBeep(0); end;

procedure TFrmDNS.EdServerKeyPress(Sender: TObject; var Key: Char);
begin EdServerChanged:=true; end;

procedure TFrmDNS.EdServerExit(Sender: TObject);
begin
 if EdServerChanged then begin          // neuen Server in ListBox einsortieren
  EdServerChanged:=false;
  EdServer.Items.Add(EdServer.Text);
  EdServer.Sorted:=true;
 end;
end;

end.
